@@ -177,11 +177,7 @@ static void cfg_version_info(void)
 #endif
 
 #ifdef SOCKS
-#ifndef SOCKS5
-  xprintf(0, gettext(" - Socks v4 proxy support\n"));
-#else
-  xprintf(0, gettext(" - Socks v5 proxy support\n"));
-#endif
+  xprintf(0, gettext(" - Socks proxy support\n"));
 #endif
 #ifdef HAVE_FSTATFS
   xprintf(0, gettext(" - filesystem free space checking\n"));
