@@ -82,13 +82,10 @@ extern int h_errno;
 #define USHRT_MAX       65535
 #endif
 
-#ifdef SOCKS
-
 #ifdef HAVE_SOCKS_H
 #include <socks.h>
-#endif
-
-#ifndef SOCKS5
+#elif defined(SOCKS)
+int SOCKSinit (char *);
 #define connect         Rconnect
 int Rconnect(int sockfd, const struct sockaddr *serv_addr, socklen_t addrlen);
 #define bind            Rbind
@@ -103,8 +100,6 @@ int  Rselect(int  n, fd_set *readfds, fd_set *writefds, fd_set *exceptfds, struc
 struct hostent *Rgethostbyname(const char *name);
 #define getsockname     Rgetsockname
 int Rgetsockname(int s, struct sockaddr  *name, socklen_t *namelen);
-#endif /* SOCKS5 */
-
 #endif /* SOCKS */
 
 #include "mt.h"
