@@ -10,8 +10,8 @@
 #define GZIP_CMD "gunzip"
 
 #ifdef NeedFunctionPrototypes
-extern int gzip_decode(char *, int, char **, int *, char *);
-extern int inflate_decode(char *, int, char **, int *, char *);
+extern int gzip_decode(char *, int, char **, ssize_t *, char *);
+extern int inflate_decode(char *, int, char **, ssize_t *, char *);
 #else
 extern int gzip_decode();
 extern int inflate_decode();
