@@ -9,9 +9,9 @@
 
 #include "dllist.h"
 
-typedef unsigned int (*dlhash_func) (unsigned int, void *key);
-typedef void *(*dlkey_func) (void *key_data);
-typedef void (*dlkeyfree_func) (void *key);
+typedef unsigned int (*dlhash_func) (unsigned int, dllist_t key);
+typedef dllist_t (*dlkey_func) (dllist_t key_data);
+typedef void (*dlkeyfree_func) (dllist_t key);
 
 typedef struct _dlhash
 {
@@ -28,13 +28,13 @@ extern dlhash *dlhash_new(unsigned int, dlkey_func, dlhash_func, dlcomp_func);
 extern void dlhash_set_free_func(dlhash *, dlfree_func, dlkeyfree_func);
 extern void dlhash_empty(dlhash *);
 extern void dlhash_free(dlhash *);
-extern void dlhash_insert(dlhash *, void *key_data);
-extern void dlhash_remove(dlhash *, void *key_data);
-extern void dlhash_exclude(dlhash *, void *key_data);
-extern void dlhash_exclude_exact(dlhash *, void *key_data);
-extern dllist *dlhash_get_class(dlhash *, void *key_data);
-extern void *dlhash_find(dlhash *, void *key_data);
-extern void *dlhash_find_by_key(dlhash *, void *key);
+extern void dlhash_insert(dlhash *, dllist_t key_data);
+extern void dlhash_remove(dlhash *, dllist_t key_data);
+extern void dlhash_exclude(dlhash *, dllist_t key_data);
+extern void dlhash_exclude_exact(dlhash *, dllist_t key_data);
+extern dllist *dlhash_get_class(dlhash *, dllist_t key_data);
+extern dllist_t dlhash_find(dlhash *, dllist_t key_data);
+extern dllist_t dlhash_find_by_key(dlhash *, dllist_t key);
 extern void dlhash_resize(dlhash *, unsigned int);
 
 #endif
