@@ -12,7 +12,6 @@
 #include <unistd.h>
 
 #ifdef GTK_FACE
-#define GTK_ENABLE_BROKEN
 #include <gtk/gtk.h>
 
 #include "icons/cancel.xpm"
@@ -226,7 +225,7 @@ static form_field_info *form_field_info_new(void)
   retv->multiple = FALSE;
   retv->selected = FALSE;
   retv->infos = NULL;
-#ifdef GTK_FACE
+#if GTK_FACE
   retv->rg = NULL;
   retv->widget = NULL;
   retv->idx = -1;
@@ -829,7 +828,7 @@ void form_get_default_successful(char *name, dllist * fields, dllist ** retv)
   }
 }
 
-#ifdef GTK_FACE
+#if GTK_FACE
 static void form_get_successful(char *name, dllist * fields, dllist ** retv)
 {
   dllist *ptr;
@@ -868,7 +867,12 @@ static void form_get_successful(char *name, dllist * fields, dllist ** retv)
         int len;
         char *p;
 
+#if GTK_FACE < 2
         len = gtk_text_get_length(GTK_TEXT(ffi->widget));
+#else
+        len = gtk_text_buffer_get_char_count(
+          gtk_text_view_get_buffer(GTK_TEXT_VIEW(ffi->widget)));
+#endif
         p = gtk_editable_get_chars(GTK_EDITABLE(ffi->widget), 0, len);
         v = tl_strdup(p);
         g_free(p);
@@ -997,12 +1001,18 @@ static void form_reset(dllist * fields)
         ffi->selected);
       break;
     case FORM_T_TEXTAREA:
+#if GTK_FACE < 2
       gtk_text_set_point(GTK_TEXT(ffi->widget), 0);
       gtk_text_forward_delete(GTK_TEXT(ffi->widget),
         gtk_text_get_length(GTK_TEXT(ffi->widget)));
       if(ffi->default_value)
         gtk_text_insert(GTK_TEXT(ffi->widget), NULL, NULL, NULL,
           ffi->default_value, strlen(ffi->default_value));
+#else
+      gtk_text_buffer_set_text(gtk_text_view_get_buffer(
+      GTK_TEXT_VIEW(ffi->widget)), ffi->default_value
+      ? ffi->default_value : "", -1);
+#endif
       break;
     default:
       break;
@@ -1289,9 +1299,17 @@ static GtkWidget *form_render(form_info * fi, GtkWidget * pbox)
       w = form_render_selection(ffi);
       break;
     case FORM_T_TEXTAREA:
+#if GTK_FACE < 2
       w = gtk_text_new(NULL, NULL);
+#else
+      w = gtk_text_view_new();
+#endif
       gtk_widget_set_usize(w, 250, 150);
+#if GTK_FACE < 2
       gtk_text_set_editable(GTK_TEXT(w), ffi->readonly);
+#else
+      gtk_text_view_set_editable(GTK_TEXT_VIEW(w), ffi->readonly);
+#endif
       break;
     case FORM_T_UNKNOWN:
     case FORM_T_OPTGROUP:
