@@ -104,8 +104,7 @@ char *form_encode_urlencoded_str(char *str)
     {
       *r = '+';
     }
-    else if(strchr(URL_RQUERY_UNSAFE, *p) ||
-      ((unsigned char) *p > 0x7f) || ((unsigned char) *p < 0x20))
+    else if(strchr(URL_RQUERY_UNSAFE, *p) || (*p > 0x7f) || (*p < 0x20))
     {
       *r = '%';
       r++;
