@@ -208,7 +208,8 @@ static int ftp_open_data_init(doc * docp)
   char *mbuf;
   struct sockaddr_storage scaddr;
   struct sockaddr *caddr;
-  int reply, n;
+  int reply;
+  socklen_t n;
 
   caddr = (struct sockaddr *) &scaddr;
 
