@@ -205,7 +205,7 @@ static void Apply(GtkObject * object, gpointer func_data)
     ai->realm = ld[5] && *ld[5] ? new_string(ld[5]) : NULL;
     ai->type = atoi(ld[6]);
 
-    authdata = dllist_append(authdata, ai);
+    authdata = dllist_append(authdata, (dllist_t)ai);
   }
   UNLOCK_AUTHINFO;
 }
