@@ -21,7 +21,7 @@
 #ifdef __CYGWIN__
 #include <windows.h>
 #include "pavukrc.h"
-#include <gdk/win32/gdkwin32.h>
+#include <gdk/gdkx.h>
 #else /* !__CYGWIN__ */
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -131,7 +131,11 @@ static GtkWidget *menu_item(gchar * field)
   if(accelerator_key != GDK_VoidSymbol)
   {
     gtk_widget_add_accelerator(item,
+#if GTK_FACE < 2
       "activate_item",
+#else
+      "activate",
+#endif
       gui_cfg.accel_group, accelerator_key, GDK_MOD1_MASK, GTK_ACCEL_LOCKED);
   }
 
