@@ -388,7 +388,7 @@ static void EnableURL(GtkObject * object, gpointer func_data)
     urlp->status &= ~URL_PROCESSED;
 
     LOCK_CFG_URLSTACK;
-    cfg.urlstack = dllist_append(cfg.urlstack, urlp);
+    cfg.urlstack = dllist_append(cfg.urlstack, (dllist_t) urlp);
     cfg.total_cnt++;
     UNLOCK_CFG_URLSTACK;
   }
