@@ -236,6 +236,8 @@ static void html_parser_process_new_base_url(html_parser_t * hpinfo,
       url_to_absolute_url(hpinfo->base, hpinfo->baset, hpinfo->doc_url,
       baseattr);
 
+    if(!newbase) return; /* collect base="" and ignore it */
+
     if((idx = strrchr(newbase, '?')))
       *idx = '\0';
     if(!tl_is_dirname(newbase))
@@ -676,6 +678,7 @@ void html_parser_parse_tag_meta_refresh(html_parser_t * hpinfo, char *stack,
         html_parser_SEXPAND(hpinfo, l);
         html_replace_url_in_stack(hpinfo->stack,
           hpinfo->current_attrib->attrib, hpinfo->tag_attrib, FALSE);
+        hpinfo->tag_attrib = 0;
       }
     }
     else
