@@ -711,10 +711,15 @@ static int http_request(doc * docp, char *method, char *data, int datalen,
   if(docp->rest_pos || docp->rest_end_pos > 0)
   {
     if(docp->rest_end_pos > 0)
-      snprintf(pom, sizeof(pom), "Range: bytes=%d-%d\r\n", docp->rest_pos,
-        docp->rest_end_pos);
+    {
+      snprintf(pom, sizeof(pom), "Range: bytes=%ld-%ld\r\n",
+      (long) docp->rest_pos, (long) docp->rest_end_pos);
+    }
     else
-      snprintf(pom, sizeof(pom), "Range: bytes=%d-\r\n", docp->rest_pos);
+    {
+      snprintf(pom, sizeof(pom), "Range: bytes=%ld-\r\n",
+      (long) docp->rest_pos);
+    }
     req = tl_str_append(req, pom);
     if(cfg.send_if_range && docp->etag)
     {
