@@ -8,6 +8,7 @@
 
 #ifdef HAVE_MOZJS
 
+#include <assert.h>
 #include <stdarg.h>
 #include <string.h>
 #include <jsapi.h>
@@ -262,7 +263,7 @@ static JSBool pjs_url_new(JSContext *cx, JSObject *obj, uintN argc, jsval *argv,
   }
 
   urlp = url_parse(JS_GetStringBytes(JSVAL_TO_STRING(argv[0])));
-  assert(purl->type != URLT_FROMPARENT);
+  assert(urlp->type != URLT_FROMPARENT);
   up = pjs_url_obj_set_url(cx, obj, urlp, NULL);
   up->free_url = TRUE;
 
@@ -434,7 +435,7 @@ static JSBool pjs_url_set_property(JSContext *cx, JSObject *obj, jsval id, jsval
     case PJSURL_STATUS:
       if(!JS_ValueToInt32(cx, *val, &status))
       {
-        JS_ReportError(cx, "PavukUrl.status: %s\n"
+        JS_ReportError(cx, "PavukUrl.status: %s\n",
           gettext("invalid assignment"));
         return JS_FALSE;
       }
@@ -640,7 +641,7 @@ static JSBool pjs_fnrules_get_property(JSContext *cx, JSObject *obj, jsval id, j
 static JSBool pjs_fnrules_get_macro(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *val)
 {
   struct lfname_lsp_interp *interp;
-  char *v;
+  const char *v;
   JSString *s;
 
   if(argc != 1 || !(s = JS_ValueToString(cx, argv[0])))
