@@ -323,8 +323,8 @@ char *lfname_get_by_url(url * urlp, const char *urlstr, const char *mime_type,
         ps++;
         nr = strtol(ps, &pp, 10);
         p1 = lfname_re_sub(lfnamep, urlstr, nr);
-        strncpy(pd, p1, sizeof(pom));
-        pd[sizeof(pom) - 1] = '\0';
+        strncpy(pd, p1, sizeof(pom)-(pd-pom));
+        pd[sizeof(pom) - (pd-pom) - 1] = '\0';
         _free(p1);
         while(*pd)
           pd++;
