@@ -75,16 +75,17 @@ static moz_pair_t *moz_pair_new(char *f, char *u)
   return rv;
 }
 
-static void moz_pair_free(moz_pair_t * mp)
+static void moz_pair_free(dllist_t dl)
 {
+  moz_pair_t * mp = (moz_pair_t *)dl;
   _free(mp->filename);
   _free(mp->urlstr);
   _free(mp);
 }
 
-static char *moz_pair_get_urlstr(moz_pair_t * mp)
+static dllist_t moz_pair_get_urlstr(dllist_t mp)
 {
-  return mp->urlstr;
+  return (dllist_t) ((moz_pair_t *)mp)->urlstr;
 }
 
 #ifdef HAVE_BDB_18x
@@ -467,7 +468,7 @@ static void moz2_read_db(char *dbname)
 
       mp = moz2_get_record_info(cmr);
       if(mp)
-        dlhash_insert(moz_hash, mp);
+        dlhash_insert(moz_hash, (dllist_t) mp);
     }
   }
 
@@ -515,9 +516,9 @@ static void moz_cache_read_db(char *dirname)
 
   if(!moz_hash)
   {
-    moz_hash = dlhash_new(256, (dlkey_func) moz_pair_get_urlstr,
-      (dlhash_func) str_hash_func, (dlcomp_func) str_comp_func);
-    dlhash_set_free_func(moz_hash, (dlfree_func) moz_pair_free, NULL);
+    moz_hash = dlhash_new(256, moz_pair_get_urlstr,
+    str_hash_func, str_comp_func);
+    dlhash_set_free_func(moz_hash, moz_pair_free, NULL);
   }
   snprintf(pom, sizeof(pom), "%s/_CACHE_MAP_", dirname);
 #ifdef HAVE_BDB_18x
@@ -539,7 +540,7 @@ char *moz_cache_find_localname(char *urlstr)
   {
     moz_pair_t *mp;
 
-    mp = dlhash_find_by_key(moz_hash, urlstr);
+    mp = (moz_pair_t *) dlhash_find_by_key(moz_hash, (dllist_t) urlstr);
 
     if(mp)
       retv = tl_strdup(mp->filename);
