@@ -236,11 +236,11 @@ static void ntlm_des_enc(unsigned char *key, unsigned char *plaintext,
 static void ntlm_des_enc(unsigned char *key, unsigned char *plaintext,
   unsigned char *result)
 {
-  GCRY_CIPHER_HD ctx;
+  gcry_cipher_hd_t ctx;
   unsigned char key64[8];
 
   ntlm_setup_des_key(key, key64);
-  ctx = gcry_cipher_open(GCRY_CIPHER_DES, GCRY_CIPHER_MODE_ECB, 0);
+  gcry_cipher_open(&ctx, GCRY_CIPHER_DES, GCRY_CIPHER_MODE_ECB, 0);
   gcry_cipher_setkey(ctx, key64, 8);
   gcry_cipher_encrypt(ctx, result, 8, plaintext, 8);
   gcry_cipher_close(ctx);
