@@ -253,7 +253,7 @@ int process_document(doc * docu, int check_lim)
     }
 #endif
     /*** to be able to revisit moved documents ***/
-    /*** especialy for authorization purposes  ***/
+    /*** especially for authorization purposes ***/
     if((urlr->status & URL_PROCESSED) && urlr->moved_to && nredir)
     {
       urlr->status &= ~URL_PROCESSED;
@@ -333,11 +333,11 @@ int process_document(doc * docu, int check_lim)
       {
         atm = time(NULL) - 86400 * cfg.ddays;
         /*
-           pro: we do not want the message
+           pro: We do not want the message
            "No transfer - file not expired"
            if the server's clock is ahead of our clock.
            If no parameter cfg.ddays is given, then
-           we do not compare the file modification times
+           we do not compare the file modification times.
          */
         if(cfg.ddays == 0 || estat.st_mtime < atm)
           docu->dtime = estat.st_mtime;
@@ -770,7 +770,7 @@ int download_single_doc(url * urlp)
 
 /*********************************************/
 /* rekurzivne prechadzanie stromu dokumentov */
-/* FIXME: Translate me                       */
+/* FIXME: Translate me!                      */
 /*********************************************/
 #ifdef HAVE_MT
 static void _recurse(int thnr)
@@ -788,6 +788,7 @@ void recurse(int thnr)
   init_global_connection_data(&con_info);
 
 /**** obsluzenie vsetkych URL v zozname ****/
+/**** FIXME: Translate me!              ****/
   while(cfg.urlstack && !cfg.stop)
   {
     doc docu;
@@ -1103,7 +1104,7 @@ void get_urls_to_resume(char *dirname)
   {
     _Xt_Serve;
 
-    sprintf(next_dir, "%s/%s", dirname, dent->d_name);
+    snprintf(next_dir, sizeof(next_dir), "%s/%s", dirname, dent->d_name);
     if(!strcmp(dent->d_name, "."))
       continue;
     if(!strcmp(dent->d_name, ".."))
@@ -1123,7 +1124,7 @@ void get_urls_to_resume(char *dirname)
     }
     else if(!strncmp(".in_", dent->d_name, 4))
     {
-      sprintf(next_dir, "%s/%s", dirname, dent->d_name + 4);
+      snprintf(next_dir, sizeof(next_dir), "%s/%s", dirname, dent->d_name + 4);
       if((purl = filename_to_url(next_dir)))
       {
         if(cfg.mode != MODE_MIRROR)
@@ -1166,7 +1167,7 @@ void get_urls_to_synchronize(char *dirname, dllist ** list)
   {
     _Xt_Serve;
 
-    sprintf(next_dir, "%s/%s", dirname, dent->d_name);
+    snprintf(next_dir, sizeof(next_dir), "%s/%s", dirname, dent->d_name);
     if(!strcmp(dent->d_name, "."))
       continue;
     if(!strcmp(dent->d_name, ".."))
@@ -1210,7 +1211,7 @@ void get_urls_to_synchronize(char *dirname, dllist ** list)
     }
     else if(!strncmp(".in_", dent->d_name, 4))
     {
-      sprintf(next_dir, "%s/%s", dirname, dent->d_name + 4);
+      snprintf(next_dir, sizeof(next_dir), "%s/%s", dirname, dent->d_name + 4);
       if((purl = filename_to_url(next_dir)))
       {
         char *ustr;
