@@ -131,7 +131,7 @@ void remind_load_db(void)
   bufio *fd;
   char buf[PATH_MAX];
 
-  sprintf(buf, "%s/.pavuk_remind_db", cfg.path_to_home);
+  snprintf(buf, sizeof(buf), "%s/.pavuk_remind_db", cfg.path_to_home);
 
   while(remind_urls)
   {
@@ -186,7 +186,7 @@ void remind_save_db(void)
   char buf[PATH_MAX];
   dllist *ptr;
 
-  sprintf(buf, "%s/.pavuk_remind_db", cfg.path_to_home);
+  snprintf(buf, sizeof(buf), "%s/.pavuk_remind_db", cfg.path_to_home);
 
   fd = bufio_copen(buf, O_BINARY | O_RDWR | O_CREAT, 0644);
 
@@ -205,7 +205,7 @@ void remind_save_db(void)
     char *p;
 
     p = url_to_urlstr(((remind_entry *) ptr->data)->urlp, FALSE);
-    sprintf(buf, "%ld %s\n", ((remind_entry *) ptr->data)->mdtm, p);
+    snprintf(buf, sizeof(buf), "%ld %s\n", ((remind_entry *) ptr->data)->mdtm, p);
     _free(p);
 
     bufio_write(fd, buf, strlen(buf));
@@ -506,7 +506,7 @@ void remind_send_result(void)
     *dp = '\0';
   }
   else
-    sprintf(buf, "mailx %s -s \"pavuk reminder result\"\n", priv_cfg.from);
+    snprintf(buf, sizeof(buf), "mailx %s -s \"pavuk reminder result\"\n", priv_cfg.from);
 
 
   fp = popen(buf, "w");
