@@ -7,9 +7,9 @@
 #ifndef _tr_h_
 #define _tr_h_
 
-extern char *tr_chr_chr(unsigned char *, unsigned char *, unsigned char *);
-extern char *tr_str_str(unsigned char *, unsigned char *, unsigned char *);
-extern char *tr_del_chr(unsigned char *, unsigned char *);
+extern char *tr_chr_chr(char *, char *, char *);
+extern char *tr_str_str(char *, char *, char *);
+extern char *tr_del_chr(char *, char *);
 extern char *tr(char *);
 
 #endif
