@@ -45,7 +45,7 @@
   {\
     char *pp[2];\
     char pom[512];\
-    ftp_handshake_info *fhi = ptr->data;\
+    ftp_handshake_info *fhi = (ftp_handshake_info *) ptr->data;\
     if (*fhi->host) sprintf(pom, "%s:%hu", fhi->host, fhi->port);\
     else pom[0] = '\0';\
     pp[0] = pom;\
@@ -208,7 +208,7 @@
     for (ptr = l; ptr; ptr = ptr->next) \
     { \
       char *pp[5]; \
-      js_transform_t *jt = ptr->data; \
+      js_transform_t *jt = (js_transform_t *) ptr->data; \
       pp[0] = jt->re->pattern; \
       pp[1] = jt->transform; \
       pp[2] = jt->tag; \
@@ -273,7 +273,7 @@
 {\
   int n;\
   for (; l; l = dllist_remove_entry(l,l))\
-    ftp_handshake_info_free(l->data);\
+    ftp_handshake_info_free((ftp_handshake_info *) l->data);\
   l = NULL;\
   for (n = 0; n < GTK_CLIST(w)->rows ; n++)\
   {\
@@ -283,7 +283,7 @@
     gtk_clist_get_text(GTK_CLIST(w), n, 1, &pp[1]);\
     fhi = ftp_handshake_info_parse(pp[0], pp[1]);\
     if (fhi)\
-      l = dllist_append(l, fhi);\
+      l = dllist_append(l, (dllist_t) fhi);\
   }\
 }
 
@@ -317,7 +317,7 @@
     gtk_clist_get_text(GTK_CLIST(w), n, 0, &xp);\
     if (ui) ui = url_info_duplicate(ui);\
     else ui = url_info_new(xp);\
-    l = dllist_append(l, ui);\
+    l = dllist_append(l, (dllist_t) ui);\
   }\
 }
 
@@ -341,10 +341,11 @@
       pr->fails = pro->fails;\
       pr->is_10 = pro->is_10;\
     }\
-    l = dllist_append(l, pr);\
+    l = dllist_append(l, (dllist_t) pr);\
   }\
   LOCK_PROXY;\
-  while (ol) {http_proxy_free(ol->data); ol = dllist_remove_entry(ol, ol);}\
+  while (ol) {http_proxy_free((http_proxy *)ol->data);\
+    ol = dllist_remove_entry(ol, ol);}\
   ol = l;\
   UNLOCK_PROXY;\
 }
@@ -353,12 +354,12 @@
 {\
   int n;\
   \
-  while(l) {_free(l->data) ; l = dllist_remove_entry(l, l);}\
+  while(l) {if(l->data) free((void *)l->data); l = dllist_remove_entry(l, l);}\
   for (n = 0 ; n < GTK_CLIST(w)->rows ; n++)\
   {\
     char *xp;\
     gtk_clist_get_text(GTK_CLIST(w), n, 0, &xp);\
-    l = dllist_append(l, tl_strdup(xp));\
+    l = dllist_append(l, (dllist_t) tl_strdup(xp));\
   }\
 }
 
@@ -466,14 +467,15 @@
     js_transform_t *jt; \
     int i,j; \
     char *pp[5]; \
-    while (l) {js_transform_free(l->data); l = dllist_remove_entry(l,l);} \
+    while (l) {js_transform_free((js_transform_t *) l->data); \
+      l = dllist_remove_entry(l,l);} \
     for (i = 0; i < GTK_CLIST(w)->rows; i++) \
     { \
       for (j = 0; j < 5; j++) \
         gtk_clist_get_text(GTK_CLIST(w), i, j, &pp[j]); \
       jt = js_transform_new(pp[0], pp[1], pp[2], pp[3], pp[4][0] == 'X'); \
       if (jt) \
-        l = dllist_append(l, jt); \
+        l = dllist_append(l, (dllist_t) jt); \
     } \
   }
 #else
@@ -526,7 +528,7 @@
       re_entry *ree = re_make(p);\
       if (ree)\
       {\
-        ptr = dllist_append(ptr, ree);\
+        ptr = dllist_append(ptr, (dllist_t) ree);\
       }\
       else\
       {\
@@ -921,7 +923,7 @@ void xset_cfg_values_comm(void)
 
     while(ptr2)
     {
-      ptr = dllist_append(ptr, ((re_entry *) ptr2->data)->pattern);
+      ptr = dllist_append(ptr, (dllist_t) ((re_entry *) ptr2->data)->pattern);
       ptr2 = ptr2->next;
     }
 
@@ -936,7 +938,7 @@ void xset_cfg_values_comm(void)
 
     while(ptr2)
     {
-      ptr = dllist_append(ptr, ((re_entry *) ptr2->data)->pattern);
+      ptr = dllist_append(ptr, (dllist_t) ((re_entry *) ptr2->data)->pattern);
       ptr2 = ptr2->next;
     }
 
@@ -960,7 +962,7 @@ void xset_cfg_values_comm(void)
 
     while(ptr)
     {
-      lfname *lf = ptr->data;
+      lfname *lf = (lfname *) ptr->data;
 
       ld[0] = (lf->type == LFNAME_FNMATCH) ? "F" : "R";
       ld[1] = lf->matchstr;
@@ -1002,7 +1004,7 @@ static dllist *make_re_list(char *str)
     }
     else
     {
-      retv = dllist_append(retv, ree);
+      retv = dllist_append(retv, (dllist_t) ree);
     }
   }
 
@@ -1333,7 +1335,7 @@ int xget_cfg_values_comm(void)
     {
       httphdr *hdr = httphdr_parse(p);
       if(hdr)
-        cfg.http_headers = dllist_append(cfg.http_headers, hdr);
+        cfg.http_headers = dllist_append(cfg.http_headers, (dllist_t) hdr);
       else
         xprintf(0, "Bad HTTP headers entry - %s\n", p);
       p = NULL;
@@ -1445,8 +1447,8 @@ int xget_cfg_values_comm(void)
 
     ree = re_make((char *) ptr->data);
     if(ree)
-      cfg.advert_res = dllist_append(cfg.advert_res, ree);
-    _free(ptr->data);
+      cfg.advert_res = dllist_append(cfg.advert_res, (dllist_t) ree);
+    if(ptr->data) free((char *)ptr->data);
     ptr = dllist_remove_entry(ptr, ptr);
   }
 
@@ -1469,8 +1471,8 @@ int xget_cfg_values_comm(void)
 
     ree = re_make((char *) ptr->data);
     if(ree)
-      cfg.js_patterns = dllist_append(cfg.js_patterns, ree);
-    _free(ptr->data);
+      cfg.js_patterns = dllist_append(cfg.js_patterns, (dllist_t) ree);
+    if(ptr->data) free((char *)ptr->data);
     ptr = dllist_remove_entry(ptr, ptr);
   }
 #endif
@@ -1501,7 +1503,7 @@ int xget_cfg_values_comm(void)
       tp = LFNAME_FNMATCH;
 #endif
       if((lfn = lfname_new(tp, ld[1], ld[2])))
-        cfg.lfnames = dllist_append(cfg.lfnames, lfn);
+        cfg.lfnames = dllist_append(cfg.lfnames, (dllist_t) lfn);
       else
       {
         _MT_CFGSTAMP;
