@@ -39,7 +39,7 @@ static char *url_decode_html(const char *, int);
 #define FS_UNSAFE_CHARACTERS "\\:*?\"<>|"
 #endif
 
-/* for hexadicimal encoding */
+/* for hexadecimal encoding */
 static const char hexa[] = "0123456789ABCDEF";
 #define HEXASC2HEXNR(x) (((x) >= '0' && (x) <= '9') ? \
   ((x) - '0') : (tl_ascii_toupper(x) - 'A' + 10))
@@ -864,9 +864,9 @@ static char *url_encode_str_real(char *urlstr, char *unsafe, int safety)
     {
       *r = '%';
       r++;
-      *r = hexa[*p >> 4];
+      *r = hexa[((unsigned char)*p) >> 4];
       r++;
-      *r = hexa[*p % 16];
+      *r = hexa[((unsigned char)*p) % 16];
     }
     else
     {
@@ -2677,7 +2677,8 @@ url *filename_to_url(char *ifn)
 
 /****************************************/
 /* zisti ci bol dokument referencovany  */
-/* v predchadzajucich cykloch   */
+/* v predchadzajucich cykloch           */
+/* FIXME: Translate me!                 */
 /****************************************/
 url *url_was_befor(url * urlp)
 {
@@ -3017,7 +3018,7 @@ url_info *url_info_parse(char *str)
       err = TRUE;
     }
 
-#if 0                           /* sometimes wee need also empty forms */
+#if 0                           /* sometimes we need also empty forms */
     if(!ui->fields && ui->method == FORM_M_GET)
       ui->type = URLI_NORMAL;
     else if(!ui->fields)
